from distutils.core import setup
setup(
  name = 'ducksouplol',         
  packages = ['ducksouplol'],   
  version = '0.1',      
  license='LICENSE.txt',        
  description = 'This is a package uploaded with OTC PyPI Uploader!',   
  author = 'oliverstech',                   
  author_email = 'imrolii9876@gmail.com',      
  url = 'https://www.google.com',   
  install_requires=[''],
  classifiers=[
    'Development Status :: 5 - Production/Stable',      
    'Intended Audience :: Developers',      
    'Topic :: Software Development :: Build Tools',
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
